@@ -9,6 +9,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.CKanMetadataPublisher;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.CKanPublisherServiceAsync;
@@ -90,6 +91,8 @@ import com.google.gwt.user.client.ui.Widget;
  */
 public class UpdateDatasetForm extends Composite {
 
+	private static final String VISIBILITY_RESTRICTED_LABEL = "Restricted";
+	private static final String VISIBILITY_PUBLIC_LABEL = "Public";
 	private static EditMetadataFormUiBinder uiBinder = GWT.create(EditMetadataFormUiBinder.class);
 
 	/**
@@ -282,6 +285,7 @@ public class UpdateDatasetForm extends Composite {
 	// error/info messages
 	protected static final String ERROR_PRODUCT_CREATION = "There was an error while trying to update the item.";
 	protected static final String PRODUCT_UPDATED_OK = "Item correctly updated!";
+	protected static final String PRODUCT_UPDATED_SUBMITTED_FOR_REVIEW_OK = "Item correctly updated and submitted for review!";
 	private static final String TRYING_TO_UPDATE_PRODUCT = "Trying to update the item, please wait...";
 	protected static final String MISSING_PUBLISH_RIGHTS = "It seems you are not authorized to edit this item. Either you must be the author item or Catalogue Admininistrator in the organization";
 
@@ -309,7 +313,7 @@ public class UpdateDatasetForm extends Composite {
 	private DatasetBean theDatasetBean;
 
 	// resource table
-	//private SelectResourceByWEMainPanel resourcesSelectByWEMainPanel;
+	// private SelectResourceByWEMainPanel resourcesSelectByWEMainPanel;
 
 	// List of opened popup'ids
 	private List<String> popupOpenedIds = new ArrayList<String>();
@@ -325,6 +329,9 @@ public class UpdateDatasetForm extends Composite {
 
 	private FlowPanel alertPanel = new FlowPanel();
 
+	// Feature #28746
+	private Boolean catalogueModerated = false;
+
 	/**
 	 * Instantiates a new update dataset form.
 	 *
@@ -393,7 +400,8 @@ public class UpdateDatasetForm extends Composite {
 
 		infoBlock.add(alertPanel);
 
-		List<String> listOfSteps = Arrays.asList("Edit Common Metadata", "Edit Item Specific Metadata & Update");
+		List<String> listOfSteps = Arrays.asList("Edit Common Metadata", "Edit Item Specific Metadata & Update",
+				"Manage Resources");
 
 		this.wizCreator = new WizardCreator(listOfSteps);
 		wizardCreatorPanel.add(wizCreator);
@@ -406,7 +414,7 @@ public class UpdateDatasetForm extends Composite {
 		continueButton.setEnabled(false);
 		resetButton.setEnabled(false);
 		addResourcesButtonStep1.setEnabled(false);
-		
+
 		// hide reset button
 		resetButton.setVisible(false);
 
@@ -458,6 +466,15 @@ public class UpdateDatasetForm extends Composite {
 								maintainerTextbox.setText(datasetBean.getMaintainer());
 								maintainerEmailTextbox.setText(datasetBean.getMaintainerEmail());
 
+								// Setting visibility, see #28736
+								boolean setPublic = datasetBean.getVisibility();
+								GWT.log("The visibility is: " + setPublic);
+								if (setPublic) {
+									visibilityListbox.setSelectedValue(VISIBILITY_PUBLIC_LABEL);
+								} else {
+									visibilityListbox.setSelectedValue(VISIBILITY_RESTRICTED_LABEL);
+								}
+
 								LoaderIcon loader = new LoaderIcon("Retrieving dataset information, please wait...");
 								setAlertBlock(null, loader, AlertType.INFO, true);
 
@@ -567,6 +584,8 @@ public class UpdateDatasetForm extends Composite {
 													final MetadataProfileBeanForUpdate metadataProfileForUpdate) {
 												setAlertBlock("", null, AlertType.ERROR, false);
 
+												GWT.log("MetadataProfileBeanForUpdate: " + metadataProfileForUpdate);
+
 												List<MetaDataProfileBean> profiles = metadataProfileForUpdate
 														.getListProfileBean();
 
@@ -817,6 +836,7 @@ public class UpdateDatasetForm extends Composite {
 
 				GWT.log("There are " + categories.size() + " categories for profile " + bean.getTitle());
 
+				// Adding fields without categories
 				if (categories == null || categories.isEmpty()) {
 					for (MetadataFieldWrapper field : fields) {
 
@@ -833,29 +853,32 @@ public class UpdateDatasetForm extends Composite {
 
 					// create the categories, then parse the fields. Fields do not belonging to a
 					// category are put at the end
+
+					// Collecting and showing the fields for categories
 					for (CategoryWrapper categoryWrapper : categories) {
-						if (categoryWrapper.getFieldsForThisCategory() != null
-								&& categoryWrapper.getFieldsForThisCategory().size() > 0) {
-							CategoryPanel cp = new CategoryPanel(categoryWrapper.getTitle(),
-									categoryWrapper.getDescription());
-							List<MetadataFieldWrapper> fieldsForThisCategory = categoryWrapper
-									.getFieldsForThisCategory();
-							fields.removeAll(fieldsForThisCategory);
 
-							for (MetadataFieldWrapper metadataFieldWrapper : fieldsForThisCategory) {
+						List<MetadataFieldWrapper> fieldsForThisCategory = fields.stream()
+								.filter(f -> f.getOwnerCategory() != null
+										&& f.getOwnerCategory().getId() == categoryWrapper.getId())
+								.collect(Collectors.toList());
 
-								MetaDataField fieldWidget;
-								try {
-									fieldWidget = new MetaDataField(metadataFieldWrapper, eventBusPublisherWidget,
-											operation);
-									cp.addField(fieldWidget);
-									listOfMetadataFields.add(fieldWidget);
-								} catch (Exception e) {
-									GWT.log("Unable to build such widget", e);
-								}
+						CategoryPanel cp = new CategoryPanel(categoryWrapper.getTitle(),
+								categoryWrapper.getDescription());
+						fields.removeAll(fieldsForThisCategory);
+
+						for (MetadataFieldWrapper metadataFieldWrapper : fieldsForThisCategory) {
+
+							MetaDataField fieldWidget;
+							try {
+								fieldWidget = new MetaDataField(metadataFieldWrapper, eventBusPublisherWidget,
+										operation);
+								cp.addField(fieldWidget);
+								listOfMetadataFields.add(fieldWidget);
+							} catch (Exception e) {
+								GWT.log("Unable to build such widget", e);
 							}
-							metadataFieldsPanel.add(cp);
 						}
+						metadataFieldsPanel.add(cp);
 					}
 
 					// add the remaining one at the end of the categories
@@ -945,7 +968,7 @@ public class UpdateDatasetForm extends Composite {
 			// add the resources to the container panel
 			if (workspaceResourcesContainer.getWidget() == null) {
 				workspaceResourcesContainer.getElement().getStyle().setMarginLeft(20, Unit.PX);
-				//workspaceResourcesContainer.add(resourcesSelectByWEMainPanel);
+				// workspaceResourcesContainer.add(resourcesSelectByWEMainPanel);
 			}
 
 		} else {
@@ -1148,7 +1171,7 @@ public class UpdateDatasetForm extends Composite {
 			theDatasetBean.setMaintainer(maintainer);
 			theDatasetBean.setMaintainerEmail(maintainerEmail);
 			theDatasetBean.setVersion(version);
-			theDatasetBean.setVisibile(visibility.equals("Public"));
+			theDatasetBean.setVisibile(visibility.equals(VISIBILITY_PUBLIC_LABEL));
 			theDatasetBean.setTitle(title);
 			theDatasetBean.setTags(new ArrayList<String>(tags));
 			theDatasetBean.setSelectedOrganization(chosenOrganization);
@@ -1182,7 +1205,11 @@ public class UpdateDatasetForm extends Composite {
 
 						final String datasetUrl = createdDatasetBean.getSource();
 
-						alertOnUpdated(PRODUCT_UPDATED_OK, false, AlertType.SUCCESS, false);
+						String successMsg = catalogueModerated != null && catalogueModerated
+								? PRODUCT_UPDATED_SUBMITTED_FOR_REVIEW_OK
+								: PRODUCT_UPDATED_OK;
+
+						alertOnUpdated(successMsg, false, AlertType.SUCCESS, false);
 
 						try {
 							// disable dataset fields
@@ -1698,4 +1725,17 @@ public class UpdateDatasetForm extends Composite {
 						|| theDatasetBean.getResourceRoot().getChildrenSize() == 0);
 
 	}
+
+	/**
+	 * Checks if is catalogue moderated.
+	 *
+	 * @return the boolean
+	 */
+	public Boolean isCatalogueModerated() {
+		return catalogueModerated;
+	}
+
+	public void setCatalogueModerated(Boolean isCatalogueModerated) {
+		this.catalogueModerated = isCatalogueModerated;
+	}
 }
\ No newline at end of file
